#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-3OOlAaB7R9ILrwDLsNf86l
key:                  ghcide-2.3.0.0-3OOlAaB7R9ILrwDLsNf86l
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  c24eb71f57967c273505969b31e4999a
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-3OOlAaB7R9ILrwDLsNf86l
depends:
    Diff-0.5-l6wPSfM0H84LgXgk88fFs Glob-0.10.2-9JGgcla180YAtORqaxExRh
    aeson-2.2.1.0-HnfSu9AKfZzFhPBHWndcTt array-0.5.6.0
    async-2.2.5-B3LTRS5ADZ11aNLUYaUoKB base-4.18.2.1
    base16-bytestring-1.0.2.0-5SHxunXITO93fpwKLO6qwm binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GnOJAdyFoN9CEG6vEkYfx
    co-log-core-0.3.2.6-ZPEyu17VpcLUr0Hf8ddQ8 containers-0.6.7
    cryptohash-sha1-0.11.101.0-1GrTSIjPfYb8a16SBmJQ8f
    data-default-0.7.1.3-Jbl1GQbSIet3IvhyjwA92u deepseq-1.4.8.1
    dependent-map-0.4.0.1-2bnq8RhCGuHFA50D8gKfnE
    dependent-sum-0.7.2.0-1jHa7X88IBUHLqYsK0hfKf directory-1.3.8.5
    dlist-1.0-4vG8aIKgFBHCUH8IlCC4Lg
    enummapset-0.7.3.0-KP6Hsv9ahHjA9urjemjm12 exceptions-0.10.7
    extra-1.7.16-JpvoJs4SC3v7weefkdu3wq filepath-1.4.300.1
    fingertree-0.1.6.2-2pHeBstKNgp9A46iLWoHmt
    focus-1.0.3.2-8TVKTimTBZODxY8FZmpwbb ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-D0If5wvCsAA12yUPk8P9yc
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-2hSfl0H3aUuEPVXanbTtzf
    hashable-1.4.7.0-IX17aYqP3drGri7tV4VHWj
    hie-bios-0.12.0-BLl7cCFVNGZHsR3W9eboey
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-4DUvXfJ6ahe1bacUZMbgXK
    hls-graph-2.3.0.0-EAIrDHZNGZc2DMPqpW7o6F
    hls-plugin-api-2.3.0.0-4ZGhd4aBCMiAsQLpy907hK
    implicit-hie-0.1.4.0-KilLVN3YFQC1Os3buv7hbM
    implicit-hie-cradle-0.5.0.1-G4alFQvQo7fAY2QpX2fYs4
    lens-5.3.4-JjT83SfukR7AuYtg8v5LHK
    list-t-1.0.5.7-LecwOUCddjdEkOnepiEP2N
    lsp-2.2.0.0-5a9cVUvDUjnDioPVLt8EQh
    lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e mtl-2.3.1
    opentelemetry-0.8.0-Bpoem92DAKQ1n31WKohBPh
    optparse-applicative-0.18.1.0-AH2zpzau3pe5hR7FNqrvmA
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-5fp5g306PJQFs6XChHaX6T
    prettyprinter-ansi-terminal-1.1.3-AkSdvHJnJ424lP1on6ghw6
    random-1.2.1.3-61dnBQTdVAfCNopGABDCH1
    regex-tdfa-1.3.2.5-IB5EKzBXbSHklLlcpMbQ
    row-types-1.0.1.2-3X77HHvGpbjD1ignZ062xN
    safe-exceptions-0.1.7.4-LTdbdfJZrJ4IcEjU8BsuGJ
    sorted-list-0.2.3.1-1SwfapLxgJoJTKUpu6w5Ny
    sqlite-simple-0.4.19.0-LeplfHSVbA1GmgE97Bi9c1 stm-2.5.1.0
    stm-containers-1.2.1.1-H7RVuY7DwyT7brUZcS2sHw
    syb-0.7.3-3hnWhpJZuWdE2NXpC0N7hI text-2.0.2
    text-rope-0.3-17d4cvn6x9y1mlGIUKhwXG time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-GeLBaTFN2PX5I8pfozEQ2D
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM
    vector-0.13.2.0-5YxFBFTVtOB5p4D1EBw8Kb

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

